betty.ancestry.locale module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.ancestry.locale module

Data types that have a locale.

class betty.ancestry.locale.HasLocale

  Bases: `Localized`, `LinkedDataDumpableJsonLdObject`

  A resource that is localized, e.g. contains information in a specific locale.

  __init__(*args: Any, locale: str = 'und', **kwargs: Any)
  async dump_linked_data(project: Project) → DumpMapping[Dump]

    Dump this instance to JSON-LD.

  async classmethod linked_data_schema(project: Project) → JsonLdObject

    Define the JSON Schema for `betty.json.linked_data.LinkedDataDumpable.dump_linked_data()`.

  property locale: str

    The locale the data in this instance is in.